import { NextResponse } from 'next/server'
import { createAchat,getAllAchat } from '@/methods/achatMethods'


 /**
 * @swagger
 * /api/achats:
 *   post:
 *     tags:
 *       - achats
 *     summary: Crée un achat
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               idUtilisateur:
 *                 type: integer
 *               idFormation:
 *                 type: integer
 *             required:
 *               - idUtilisateur
 *               - idFormation
 *     responses:
 *       201:
 *         description: achat créé
 */

export async function POST(request: Request) {
    const body = await request.json()
    const{idUtilisateur,idFormation} = body

    const result = await createAchat(idUtilisateur,idFormation)   
    return NextResponse.json(result, { status: 201 })
}


/**
 * @swagger
 * /api/achats:
 *   get:
 *     tags : 
 *      - achats
 *     summary: Lister les achats
 *     description: Retourne l'ensemble des achats
 *     responses:
 *       200:
 *         description: liste des achats
 */
export async function GET(){
    const result = await getAllAchat()
    return NextResponse.json(result, { status: 200 })
}
