import { NextResponse } from 'next/server'
import { createFormation,deleteFormation,getAllFormation } from '@/methods/formationMethods'


 /**
 * @swagger
 * /api/formations:
 *   post:
 *     tags:
 *       - formations
 *     summary: Crée une formations
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               titre:
 *                 type: string
 *               description:
 *                 type: string
 *               prix : 
 *                 type : string
 *             required:
 *               - titre
 *               - description
 *               - prix
 *     responses:
 *       201:
 *         description: formation créé
 */

export async function POST(request: Request) {
    const body = await request.json()
    const{titre,description,prix} = body

    const result = await createFormation(titre,description,prix)   
    return NextResponse.json(result, { status: 201 })
}

/**
 * @swagger
 * /api/formations:
 *   get:
 *     tags : 
 *      - formations
 *     summary: Lister toutes les formations 
 *     description: Retourne l'ensemble des formations
 *     responses:
 *       200:
 *         description: liste des formations
 */

export async function GET(){
    const result = await getAllFormation()
    return NextResponse.json(result, { status: 200 })
}

/**
 * @swagger
 * /api/formations:
 *   delete:
 *     tags : 
 *      - formations
 *     summary: delete une formations  
 *     description: delete une formations  
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               id:
 *                 type: number
 *             required:
 *               - id
 *     responses:
 *       200:
 *         description: liste des formations
 */

export async function DELETE(request : Request){
    const body = await request.json()
    const {id } = body
    const result = await deleteFormation(id)

    return NextResponse.json(result,{status : 200})
}
