
import { NextResponse } from 'next/server'
import { createUserMethod,deleteUser,getAllUser } from '@/methods/userMethods'



 /**
 * @swagger
 * /api/users:
 *   post:
 *     tags:
 *       - utilisateurs
 *     summary: Crée un utilisateur
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               name:
 *                 type: string
 *               prenom:
 *                 type: string
 *               email:
 *                 type: string
 *             required:
 *               - name
 *               - prenom
 *               - email
 *     responses:
 *       201:
 *         description: utilisateur créé
 */


export async function POST(request: Request) {
  const body = await request.json()
  const { name, prenom,email } = body

  if (!name || !email) {
    return NextResponse.json({ error: 'Champs manquants' }, { status: 400 })
  }

  const user = await createUserMethod(name,prenom, email)
  return NextResponse.json(user, { status: 201 })
}


/**
 * @swagger
 * /api/users:
 *   get:
 *     tags : 
 *      - utilisateurs
 *     summary: Lister les utilisateurs
 *     description: Retourne l'ensemble des utilisateurs
 *     responses:
 *       200:
 *         description: liste des utilisateurs
 */


export async function GET() {
  const user = await getAllUser()
  return NextResponse.json(user, { status: 200 })
}

/**
 * @swagger
 * /api/users:
 *   delete:
 *     tags : 
 *      - utilisateurs
 *     summary: delete un utilisateur  
 *     description: delete un utilisateur
 *     requestBody:
 *       required: true
 *       content:
 *         application/json:
 *           schema:
 *             type: object
 *             properties:
 *               id:
 *                 type: number
 *             required:
 *               - id
 *     responses:
 *       200:
 *         description: suppression de l'utilisateur
 */

export async function DELETE(request : Request){
  const param = await request.json()
  const { id } = param
  
  const user = deleteUser(parseInt(id))

  return NextResponse.json(user,{status : 200})
}

